c ######################################################################
c #
c #                  INCOLOY 908 PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of Incoloy 908 (SMC Inco superalloy)
c #
c ######################################################################

c ######################################################################
      real function dIncoloy908(T)
c ######################################################################
c #
c # Density of Incoloy 908
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # L.S.Toma, M.M.Steeves, R.P.Reed, Incoloy Alloy 908 Data Handbook, 
c # PFC/RR-94-2, 1994
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dIncoloy908       x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dIncoloy908 = 8107.0
c *

      return
      end
c ######################################################################
      real function cIncoloy908(T)
c ######################################################################
c #
c # Density of Incoloy 908
c #
c # Range: 4.27 <= T <= 1423 K
c #
c #                        References
c #                        ----------
c # L.S.Toma, M.M.Steeves, R.P.Reed, Incoloy Alloy 908 Data Handbook, 
c # PFC/RR-94-2, 1994
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cIncoloy908       x    specific heat                     J/Kg K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0
      real     AA1,BB1,CC1,DD1,a1,b1,c1,d1,na1,nb1,nc1,nd1
      real     AA2,BB2,CC2,DD2,a2,b2,c2,d2,na2,nb2,nc2,nd2
      real     Tmin,Tmax
      data     AA1  / 0.003200345  / ,  BB1  / 0.132240373 / ,
     &         CC1  / 0.000334011  / ,  DD1  /-8.99126E-06 / 
      data     a1   /  4812.828489 / ,  b1   /  8.47734657 / ,
     &         c1   / 71.76062421  / ,  d1   / 249.3115182 / 
      data     na1  / -0.19359062  / ,  nb1  / 1.493467866 / ,
     &         nc1  /  3.54377032  / ,  nd1  / 3.372306335 / 
      data     AA2  / 0.002191811  / ,  BB2  /  0.078538241 / ,
     &         CC2  / 0.000206767  / ,  DD2  / -9.89807E-06 / 
      data     a2   /  4813.25594  / ,  b2   /  5.161492796 / ,
     &         c2   / 84.98587122  / ,  d2   / 110.6516732  / 
      data     na2  /-0.224454629  / ,  nb2  / -0.451330848 / ,
     &         nc2  /  3.397742345 / ,  nd2  /  2.724838279 / 
      data     T0   / 715.4270056/
      data     Tmin /   4.27/, Tmax / 1423.0/
      save    
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)
      
      if(TT.le.T0) then
         cIncoloy908 = AA1*TT**na1/(1+TT/a1)**na1 + 
     &                 BB1*TT**nb1/(1+TT/b1)**nb1 + 
     &                 CC1*TT**nc1/(1+TT/c1)**nc1 + 
     &                 DD1*TT**nd1/(1+TT/d1)**nd1       
      else
         cIncoloy908 = AA2*TT**na2/(1+TT/a2)**na2 + 
     &                 BB2*TT**nb2/(1+TT/b2)**nb2 + 
     &                 CC2*TT**nc2/(1+TT/c2)**nc2 + 
     &                 DD2*TT**nd2/(1+TT/d2)**nd2       
      endif
c *
      return
      end
c ######################################################################
      real function kIncoloy908(T)
c ######################################################################
c #
c # Thermal conductivity of Incoloy 908
c #
c # Range: 5.14 <= T <= 1423 K
c #
c #                        References
c #                        ----------
c # L.S.Toma, M.M.Steeves, R.P.Reed, Incoloy Alloy 908 Data Handbook, 
c # PFC/RR-94-2, 1994
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kIncoloy908       x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     T0
      real     AA1,BB1,CC1,DD1,a1,b1,c1,d1,na1,nb1,nc1,nd1
      real     AA2,BB2,CC2,DD2,a2,b2,c2,d2,na2,nb2,nc2,nd2
      real     Tmin,Tmax
      data     AA1  / 0.091353842 / ,  BB1  / 0.48792346  / ,
     &         CC1  / 1.003802484 / ,  DD1  / 6.899330693 / 
      data     a1   / 1.031497926 / ,  b1   / 9.063742107 / ,
     &         c1   / 16.70886392 / ,  d1   / 25.25592733 / 
      data     na1  / 1.181346689 / ,  nb1  / 1.540225727 / ,
     &         nc1  / 2.9422274   / ,  nd1  / 4.048268782 / 
      data     AA2  / 16.34448119 / ,  BB2  / -14.47784219  / ,
     &         CC2  / 22.31481305 / ,  DD2  /  20.38187961  / 
      data     a2   / 185.0788967 / ,  b2   / 392.7887998   / ,
     &         c2   / 525.7445401 / ,  d2   / 419.5527053   / 
      data     na2  / 0.957484739 / ,  nb2  /   1.948172125 / ,
     &         nc2  / 3.037199008 / ,  nd2  /   3.902290487 / 
      data     T0   / 86.75983576 /
      data     Tmin /   4.27/, Tmax / 1423.0/
      save    
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)
      
      if(TT.le.T0) then
         kIncoloy908 = AA1*TT   /(a1+TT)**na1 + 
     &                 BB1*TT**2/(b1+TT)**nb1 + 
     &                 CC1*TT**3/(c1+TT)**nc1 + 
     &                 DD1*TT**4/(d1+TT)**nd1       
      else
         kIncoloy908 = AA2*TT   /(a2+TT)**na2 + 
     &                 BB2*TT**2/(b2+TT)**nb2 + 
     &                 CC2*TT**3/(c2+TT)**nc2 + 
     &                 DD2*TT**4/(d2+TT)**nd2       
      endif
c *

      return
      end
c ######################################################################
      real function rIncoloy908(T)
c ######################################################################
c #
c # Electrical resistivity of Incoloy 908
c #
c # Range: 300 <= T <= 873.15 K
c #
c #                        References
c #                        ----------
c # http://nickel-wire-mesh.en.hisupplier.com/product-1055779-Incoloy-
c # 907-908-909-Wire-Mesh-Screen.html
c # http://specialmetals.ir/images/technical_info/Fer-base/Incoloy-alloy-
c # 908.pdf
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rIncoloy908       x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     rho0,B,T0,n
      real     Tmin,Tmax
      data     rho0  /  0.6 /
      data     B     /  0.69519249 /
      data     T0    /  518.245399 /
      data     n     /  4.32988874 /
      data     Tmin   / 300.0/, Tmax   / 873.15/
      save
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      rIncoloy908 = (rho0+B*(T/T0)**n / (1+(TT/T0)**n))*1e-6
	
c *
      return
      end
